<?php

/*
Plugin Name: افزونه کارت به کارت پی استار برای افزونه ووکامرس وردپرس
Plugin URI: https://card.card_paystar.ir
Description: <b> افزونه کارت به کارت پی استار برای افزونه ووکامرس وردپرس </b>
Version: 1.0
Author: ماژول بانک
Author URI: https://www.modulebank.ir
 */

function woocommerce_card_paystar_init()
{
	load_plugin_textdomain('card_paystar-payment-for-woocommerce', false, basename(dirname(__FILE__)) . '/languages');
	if (!class_exists('WC_Payment_Gateway')) return;
	class WC_CardPayStar extends WC_Payment_Gateway
	{
		public function __construct()
		{
			$this->id = 'card_paystar';
			$this->method_title = __('CardPayStar Payment Gateway', 'card_paystar-payment-for-woocommerce');
			$this->icon = plugin_dir_url(__FILE__).'images/logo.png';
			$this->has_fields = false;
			$this->init_form_fields();
			$this->init_settings();
			$this->title = $this->settings['title'];
			$this->description = $this->settings['description'];
			$this->terminal = $this->settings['terminal'];
			add_action('woocommerce_api_' . strtolower(get_class($this)), array($this, 'check_card_paystar_response'));
			add_action('valid-card_paystar-request', array($this, 'successful_request'));
			add_action('woocommerce_update_options_payment_gateways_card_paystar', array($this, 'process_admin_options'));
			add_action('woocommerce_receipt_card_paystar', array($this, 'receipt_page'));
		}

		function init_form_fields()
		{
			$this->form_fields = array(
				'enabled' => array(
					'title' => __('Enable / Disable', 'card_paystar-payment-for-woocommerce'),
					'type' => 'checkbox',
					'label' => __('Enable or Disable This Payment Mehod', 'card_paystar-payment-for-woocommerce'),
					'default' => 'yes'),
				'title' => array(
					'title' => __('Display Title', 'card_paystar-payment-for-woocommerce'),
					'type'=> 'text',
					'description' => __('Display Title', 'card_paystar-payment-for-woocommerce'),
					'default' => __('CardPayStar Payment Gateway', 'card_paystar-payment-for-woocommerce')),
				'description' => array(
					'title' => __('Payment Instruction', 'card_paystar-payment-for-woocommerce'),
					'type' => 'textarea',
					'description' => __('Payment Instruction', 'card_paystar-payment-for-woocommerce'),
					'default' => __('Pay by CardPayStar Payment Gateway', 'card_paystar-payment-for-woocommerce')),
				'terminal' => array(
					'title' => __('CardPayStar Terminal', 'card_paystar-payment-for-woocommerce'),
					'type' => 'text',
					'description' => __('Enter CardPayStar Terminal', 'card_paystar-payment-for-woocommerce')),
				);
		}

		public function admin_options()
		{
			echo '<h3>'.__('CardPayStar Payment Gateway', 'card_paystar-payment-for-woocommerce').'</h3>';
			echo '<table class="form-table">';
			$this->generate_settings_html();
			echo '</table>';
		}

		function payment_fields()
		{
			if($this->description) echo wpautop(wptexturize($this->description));
		}

		function receipt_page($order)
		{
			echo '<p>'.__('thank you for your order. please note the order id. and then click on pay button', 'card_paystar-payment-for-woocommerce').'</p>';
			echo $this->generate_card_paystar_form($order);
       }

		function process_payment($order_id)
		{
			$order = new WC_Order($order_id);
			return array('result' => 'success', 'redirect' => $order->get_checkout_payment_url(true)); 
		}

		function check_card_paystar_response()
		{
			global $woocommerce;
			if (isset($_GET['amp;order_id']) || isset($_GET['order_id']))
			{
			    if (isset($_GET['amp;order_id'])){
                    list($order_id, $nothing) = explode('#', $_GET['amp;order_id']);
                    $order = new WC_Order($order_id);
                }elseif (isset($_GET['order_id'])){
                    list($order_id, $nothing) = explode('#', $_GET['order_id']);
                    $order = new WC_Order($order_id);
                }

				if($order->status != 'completed')
				{
					require_once(dirname(__FILE__) . '/cardpaystar_payment_helper.class.php');
					$p = new CardPayStar_Payment_Helper($this->terminal);
					$r = $p->paymentVerify($x = array_merge($_GET, array('amount' => ($order->order_total * (get_woocommerce_currency() == 'IRHT' ? 10000 : (get_woocommerce_currency() == 'IRT' ? 10 : 1))))));
					if ($r)
					{
						$message = sprintf(__("Payment Completed. OrderID : %s . PaymentRefrenceID : %s", 'card_paystar-payment-for-woocommerce'), $order_id, $p->txn_id);
						$order->payment_complete();
						$order->add_order_note($message);
						$woocommerce->cart->empty_cart();
						wc_add_notice($message, 'success');
						wp_redirect(add_query_arg('wc_status', 'success', $this->get_return_url($order)));
						exit;
					}
					else
					{
						$message = $p->error;
						$order->add_order_note($message);
					}
				}
				else
				{
					$message = __('Error : Order Not Exists OR Already Paid!', 'card_paystar-payment-for-woocommerce');
				}
			}
			else
			{
				$message = __('System (Permission) Error.', 'card_paystar-payment-for-woocommerce');
			}
			if (isset($message) && $message) wc_add_notice($message, 'error');
			wp_redirect($woocommerce->cart->get_checkout_url());
			exit;
		}

		public function generate_card_paystar_form($order_id)
		{
			global $woocommerce;
			$order = new WC_Order($order_id);
			require_once(dirname(__FILE__) . '/cardpaystar_payment_helper.class.php');
			$p = new CardPayStar_Payment_Helper($this->terminal);
			$r = $p->paymentRequest(array(
					'amount'      => ($order->order_total * (get_woocommerce_currency() == 'IRHT' ? 10000 : (get_woocommerce_currency() == 'IRT' ? 10 : 1))),
					'order_id'    => $order_id . '#' . time(),
					//'name'        => $order->get_formatted_shipping_full_name(),
					//'phone'       => $order->get_billing_phone(),
					//'mail'        => $order->get_billing_email(),
					//'description' => 'WC-Order#'.$order_id,
					'callback_url'    => add_query_arg(array('wc-api' => get_class($this), 'order_id' => $order_id), get_site_url().'/'),
                    'token' => $this->terminal
				));
			if ($r)
			{
				update_post_meta($order_id, 'card_paystar_token', $r->token);
				$newURL = 'https://card.paystar.ir/check?token='.$r->token;
                header('Location: '.$newURL);
			}
			else
			{
				echo $p->error;
			}
		}
	}

	function woocommerce_add_card_paystar_gateway($methods)
	{
		$methods[] = 'WC_CardPayStar';
		return $methods;
	}
	add_filter('woocommerce_payment_gateways', 'woocommerce_add_card_paystar_gateway');
}
add_action('plugins_loaded', 'woocommerce_card_paystar_init', 666);

?>